<?php
if ( ! function_exists( 'edu_light_set_global' ) ) :
/**
 * Setting global values for all saved customizer values
 *
 * @since edu-light 1.0.0
 *
 * @param null
 * @return null
 *
 */
function edu_light_set_global() {
    /*Getting saved values start*/
    $GLOBALS['edu_light_customizer_all_values'] = edu_light_get_all_options(1);
}
endif;
add_action( 'edu_light_action_before_head', 'edu_light_set_global', 0 );

if ( ! function_exists( 'edu_light_doctype' ) ) :
/**
 * Doctype Declaration
 *
 * @since edu-light 1.0.0
 *
 * @param null
 * @return null
 *
 */
function edu_light_doctype() {
    ?>
    <!DOCTYPE html>
    <html <?php language_attributes(); ?>>
<?php
}
endif;
add_action( 'edu_light_action_before_head', 'edu_light_doctype', 10 );

if ( ! function_exists( 'edu_light_before_wp_head' ) ) :
/**
 * Before wp head codes
 *
 * @since edu-light 1.0.0
 *
 * @param null
 * @return null
 *
 */
function edu_light_before_wp_head() {
    ?>
        <meta charset="<?php bloginfo( 'charset' ); ?>">
        <meta name='viewport' content='width=device-width, initial-scale=1.0, maximum-scale=1.0'/>
        <link rel="profile" href="http://gmpg.org/xfn/11">
        <link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>">
<?php
}
endif;
add_action( 'edu_light_action_before_wp_head', 'edu_light_before_wp_head', 10 );

if( ! function_exists( 'edu_light_default_layout' ) ) :
    /**
     * edu-light default layout function
     *
     * @since  edu-light 1.0.0
     *
     * @param int
     * @return string
     */
    function edu_light_default_layout( $post_id = null ){

        global $edu_light_customizer_all_values,$post;
        $edu_light_default_layout = $edu_light_customizer_all_values['edu-light-default-layout'];
        if( is_home()){
            $post_id = get_option( 'page_for_posts' );
        }
        if( null == $post_id && isset ( $post->ID ) ){
            $post_id = $post->ID;
        }
        $edu_light_default_layout_meta = get_post_meta( $post_id, 'edu-light-default-layout', true );

        if( false != $edu_light_default_layout_meta ) {
            $edu_light_default_layout = $edu_light_default_layout_meta;
        }
        return $edu_light_default_layout;
    }
endif;

if ( ! function_exists( 'edu_light_body_class' ) ) :
/**
 * add body class
 *
 * @since edu-light 1.0.0
 *
 * @param null
 * @return null
 *
 */
function edu_light_body_class( $edu_light_body_classes ) {
  global $edu_light_customizer_all_values;
  $edu_light_alternate_layout = '';
    if ($edu_light_customizer_all_values['edu-light-alternate-layout'] == 1) {
      $edu_light_alternate_layout = " alternate";
    } else {
      $edu_light_alternate_layout = " non-alternate";
    }

    if(!is_front_page() || ( is_front_page())){
        $edu_light_default_layout = edu_light_default_layout();
        if( !empty( $edu_light_default_layout ) ){
            if( 'left-sidebar' == $edu_light_default_layout ){
                $edu_light_body_classes[] = 'evision-left-sidebar'. $edu_light_alternate_layout;
            }
            elseif( 'right-sidebar' == $edu_light_default_layout ){
                $edu_light_body_classes[] = 'evision-right-sidebar'. $edu_light_alternate_layout;
            }
            elseif( 'both-sidebar' == $edu_light_default_layout ){
                $edu_light_body_classes[] = 'evision-both-sidebar' . $edu_light_alternate_layout;
            }
            elseif( 'no-sidebar' == $edu_light_default_layout ){
                $edu_light_body_classes[] = 'evision-no-sidebar'. $edu_light_alternate_layout;
            }
            else{
                $edu_light_body_classes[] = 'evision-right-sidebar'. $edu_light_alternate_layout;
            }
        }
        else{
            $edu_light_body_classes[] = 'evision-right-sidebar'. $edu_light_alternate_layout;
        }
    }
    return $edu_light_body_classes;

}
endif;
add_filter( 'body_class', 'edu_light_body_class', 10, 1);

if ( ! function_exists( 'edu_light_before_page_start' ) ) :
/**
 * intro loader
 *
 * @since edu-light 1.0.0
 *
 * @param null
 * @return null
 *
 */
function edu_light_before_page_start() {
    global $edu_light_customizer_all_values;
    /*intro loader*/
}
endif;
add_action( 'edu_light_action_before', 'edu_light_before_page_start', 10 );

if ( ! function_exists( 'edu_light_page_start' ) ) :
/**
 * page start
 *
 * @since edu-light 1.0.0
 *
 * @param null
 * @return null
 *
 */
function edu_light_page_start() {
?>
    <div id="page" class="site clearfix">
<?php
}
endif;
add_action( 'edu_light_action_before', 'edu_light_page_start', 15 );

if ( ! function_exists( 'edu_light_skip_to_content' ) ) :
/**
 * Skip to content
 *
 * @since edu-light 1.0.0
 *
 * @param null
 * @return null
 *
 */
function edu_light_skip_to_content() {
    ?>
    <a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'edu-light' ); ?></a>
<?php
}
endif;
add_action( 'edu_light_action_before_header', 'edu_light_skip_to_content', 10 );
   
   if ( ! function_exists( 'edu_light_navigation_page_start' ) ) :
   /**
    * Skip to content
    *
    * @since edu-light 1.0.0
    *
    * @param null
    * @return null
    *
    */
   function edu_light_navigation_page_start() {
       global $edu_light_customizer_all_values; 
       ?>
      <div id="preloader"><!-- pre loader -->
        <div id="status">&nbsp;</div>
      </div><!-- end of pre loader -->
        
    <header id="masthead" class="site-header">
        <?php if ( 1 == $edu_light_customizer_all_values['edu-light-top-header-enable'])
        { ?>

      <section class="top-header">
        <?php $edu_light_phone = esc_html($edu_light_customizer_all_values['edu-light-top-header-phone']);
        $edu_light_gmail = esc_html($edu_light_customizer_all_values['edu-light-top-header-email']);
        $edu_light_opening_hours = esc_html($edu_light_customizer_all_values['edu-light-top-header-opening-hours']);
        $edu_light_location = esc_html($edu_light_customizer_all_values['edu-light-top-header-location']);
        $edu_light_button = esc_html($edu_light_customizer_all_values['edu-light-top-header-button']);
        $edu_light_button_url = esc_url($edu_light_customizer_all_values['edu-light-top-header-button-url']);
        ?>
        <div class="container">
          <div class="row">
            <div class="col-md-12">
              <div class="edu-top-bar">
                <div class="col-md-5 col-xs-5 col-sm-5">
                  <div class="edu-contact-list">
                    <?php if (!empty($edu_light_phone) && !empty($edu_light_gmail) ) { ?>
                      <ul>
                        <li><i class="fa fa-phone"></i><a href="#"><?php echo esc_html($edu_light_phone); ?></a></li>
                        <li><i class="fa fa-envelope"></i><a href="#"><?php echo esc_html($edu_light_gmail); ?></a></li>
                      </ul>
                    <?php } ?>  
                  </div><!-- contact list -->
                </div><!-- col-md-5 -->
                <div class="col-md-7 col-xs-7 col-sm-7">
                  <div class="openaning-hours right">
                    <?php if (!empty($edu_light_opening_hours) && !empty($edu_light_location) && !empty($edu_light_button)  )  { ?>
                    <ul>
                      <li><i class="fa fa-clock-o"></i><?php echo esc_html($edu_light_opening_hours); ?></li>
                      <li><i class="fa fa-map-signs"></i><?php echo esc_html($edu_light_location); ?></li>
                      <li class="hidden-sm"><a href="<?php echo esc_url($edu_light_button_url); ?>" class="btn-white"><?php echo esc_html($edu_light_button); ?></a></li>
                    </ul> 
                    <?php } ?>                
                  </div><!-- openaning-hours right -->
                </div><!-- col-md-7 col-xs-7 col-sm-7 -->
              </div><!-- top-bar -->
            </div>  <!-- mdd 12 -->       
          </div><!-- row -->
        </div><!-- container -->        
      </section><!-- top header section -->
      <?php }
        ?>
      <section class="nav-section">
        <div class="container edu-nav-wrapper">
          <div class="col-md-4 col-xs-8 col-sm-8">
            <div class="site-branding">
              <?php
              the_custom_logo();
              if ( is_front_page() && is_home() ) : ?>
                <h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
              <?php else : ?>
                <p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
              <?php
              endif;

              $description = get_bloginfo( 'description', 'display' );
              if ( $description || is_customize_preview() ) : ?>
                <p class="site-description"><?php echo esc_html($description); /* WPCS: xss ok. */ ?></p>
              <?php
              endif; ?>
            </div><!-- .site-branding -->
          </div><!-- col-md-4 -->
          <div class="col-md-8 col-xs-4 col-sm-4 edu-nav-manage">        
            <button class="menu-toggler" id="menu-icon">
              <span></span>
              <span></span>
              <span></span>
              <span></span>
            </button>         
            <nav id="site-navigation" class="main-navigation">             
              <?php
                wp_nav_menu( array(
                  'theme_location' => 'menu-1',
                  'menu_id'        => 'primary-menu',
                  'fallback_cb'    => 'edu_light_primary_menu_callback'
                ) );
              ?>
            </nav><!-- #site-navigation -->
            <?php if (0 != $edu_light_customizer_all_values['edu-light-top-header-social-button-enable'] ) { ?>
            <i class="fa fa-share-alt social-section"></i> 
             <?php  } ?>          
          </div><!-- col-md-12 -->
          <div class="edu-social-nav">            
              <div class="social-widget evision-social-section social-icon-only bottom-tooltip">
                  <?php
                      wp_nav_menu( array( 
                          'theme_location' => 'social', 
                          'link_before' => '<span>',
                          'link_after'=>'</span>' , 
                          'menu_id' => 'social-menu',
                          'fallback_cb' => 'edu_light_social_menu_callback',
                      ) );
                  ?>
              </div>              
          </div><!--edu-social-nav -->
        </div><!-- container -->         
      </section><!-- nav-section -->
    </header><!-- #masthead -->
           


<div id="content" class="site-content">
<?php if (  is_front_page() && !is_home() )
        {?>
       <!--  <div id="content" class="site-content">
            <div id="primary" class="content-area">
                <main id="main" class="site-main" role="main"> -->
            <?php } 
            else
            {
              
                do_action('edu-light-page-inner-title');
            }?>
<?php
}
endif;
add_action( 'edu_light_action_nav_page_start', 'edu_light_navigation_page_start', 10 );


if( ! function_exists( 'edu_light_main_slider_setion' ) ) :
/**
 * Main slider
 *
 * @since edu-light 1.0.0
 *
 * @param null
 * @return null
 *
 */
    function edu_light_main_slider_setion(){
        if (  is_front_page() && !is_home() ) {
            do_action('edu_light_action_main_slider');
        } else {
            /**
             * edu_light_action_after_title hook
             * @since edu-light 1.0.0
             *
             * @hooked null
             */
            do_action( 'edu_light_action_after_title' );
        }
    }
endif;
add_action( 'edu_light_action_on_header', 'edu_light_main_slider_setion', 10 );



if( ! function_exists( 'edu_light_add_breadcrumb' ) ) :

/**
 * Breadcrumb
 *
 * @since edu-light 1.0.0
 *
 * @param null
 * @return null
 *
 */
    function edu_light_add_breadcrumb(){
        global $edu_light_customizer_all_values;
        // Bail if Breadcrumb disabled
        $breadcrumb_enable_breadcrumb = $edu_light_customizer_all_values['edu-light-enable-breadcrumb' ];
        if ( 1 != $breadcrumb_enable_breadcrumb ) {
            return;
        }
        // Bail if Home Page
        if ( is_front_page() || is_home() ) {
            return;
        }
        echo '<div id="breadcrumb" class="breadcrumb-wrap">';
          echo '<div class="container">';
            edu_light_simple_breadcrumb();
          echo '</div><!-- container -->';
        echo '</div><!-- #breadcrumb -->';
    }
endif;
add_action( 'edu_light_action_after_title', 'edu_light_add_breadcrumb', 10 );